% this function assumes the image to contain patches of the same color
% it returns a SA_VectorArray containing all borders of the patches.
%
% A border is a list of (x,y) position pairs
%
% the algorithm assumes the areas with color black (0,0,0) to be 
% already visited

function BoundaryList = getBoundaries(Image);
if (nargin<1) 
    error('Input Image missing.');
end

c = [uint8(0), uint8(0), uint8(0)];

BoundaryList = SA_VectorArray; 

% create a bitmask with the same size as Image and all entries false that
% not contain 
for (x=1:Image.x)
    for (y=1:Image.y) % black (0,0,0) is interpreted as empty
        if (get(Image,x,y) == c)
        else
            BMask = getPatchBitmask(Image.img, x, y);
            boundary = traceBoundary(BMask); % returns the boundary of the bitmask
            BoundaryList = insert(BoundaryList, boundary);
            Image = removePatch(Image,BMask);
        end
    end
end 



% sets the color of the image to (0,0,0) where the bitmask has 1 (true)
% returns new image
function Image = removePatch(Image, Bitmask);
    Image.img(:,:,1) = uint8(double(Image.img(:,:,1)) .* double(~Bitmask));
    Image.img(:,:,2) = uint8(double(Image.img(:,:,2)) .* double(~Bitmask));
    Image.img(:,:,3) = uint8(double(Image.img(:,:,3)) .* double(~Bitmask));
%end removePatch