% SA_createPatchBitmask takes a source image (with size m x n x 3) and computes
% a bitmask with ones for the whole region where the image has the same 
% color as in [start_x, start_y].
function Bitmask = getPatchBitmask(SrcImg, start_x, start_y);
if (nargin<3)
    error('Too less input parameter');
end

img_size = size(SrcImg);

% init bitmask and visited mask
Bitmask = zeros(img_size(1),img_size(2));
Visited = zeros(img_size(1),img_size(2));

%list of points to be looked at:
pointList = [[start_x,start_y]]; 
color = SrcImg(start_x, start_y, :);
Bitmask(start_x, start_y) = true;
Visited(start_x, start_y) = true;

%processing loop
while (size(pointList,1)>0)    
    x = pointList(end,1);
    y = pointList(end,2);
    %remove last point pair from list as its going to be looked at
    pointList = pointList(1:end-1, :);
    
    %look at first point on the list:
    if (SrcImg(x, y, :) == color) %if same color        
        Bitmask(x,y) = true;
        
        %add its neighbors to the processing list
        %west
        if (x-1>0) %point in image
            if (~Visited(x-1,y)) %point not looked at yet
                pointList = [pointList;[x-1,y]]; %add point to process list 
                Visited(x-1,y) = true;
            end
        end
    
        %east
        if (x+1 <= img_size(1)) %point in image
            if (~Visited(x+1,y)) %point not looked at yet
                pointList = [pointList;[x+1,y]]; %add point to process list  
                Visited(x+1,y) = true;
            end
        end
    
        %north
        if (y-1>0) %point in image
            if (~Visited(x,y-1)) %point not looked at yet
                pointList = [pointList;[x,y-1]]; %add point to process list 
                Visited(x,y-1) = true;    
            end
        end
    
        %south
        if (y+1 <= img_size(2)) %point in image
            if (~Visited(x,y+1)) %point not looked at yet
                pointList = [pointList;[x,y+1]]; %add point to process list 
                Visited(x,y+1) = true;    
            end
        end
    end %img color(x,y) == color
end %while
% end SA_createAreaBitmask

