% SA_traceBoundary takes a bitmap matrix as argument and returns a vector
% of [x, y] pairs that represent the boundary of the bitmask. The algorithm
% assumes that 1 is the region of interest and 0 is the other part. It also
% takes only one area of 1's into account (the first it finds);
function Boundary = traceBoundary(Bitmask);
img_size = size(Bitmask);

old_pos = [1,0]; 
start_pos = [0,0];
found = false;


% find the patch with 1's (by finding the first change from 0 to 1)
for (x=1:img_size(1))
    for (y=1:img_size(2))
        if (~found) % found border
            if (Bitmask(x,y)) % found
                found = true;
                start_pos = [x,y];
            else % not found
                old_pos = [x,y];
            end
        end   
    end
end

cur_pos = start_pos; 
delta = start_pos - old_pos; %step vector for the algorithm


if (delta(1)^2 + delta(2)^2 == 1) % delta's length should be = 1
    % make first step so we can use the start_pos as end_pos too
    Boundary = start_pos;
    
    tmp_delta = [-delta(2), delta(1)]; % turn_left
    tmp_pos = cur_pos + tmp_delta;
    if (Bitmask(tmp_pos(1), tmp_pos(2))) %no left turn if the new bit is 0. 
        delta = tmp_delta;               %this prevents diagonal paths at stairs
    end
    cur_pos = cur_pos + delta;
    
    
    % step clockwise around the 1-area
    while ~((cur_pos(1) == start_pos(1)) & (cur_pos(2) == start_pos(2)))
        
        if (Bitmask(cur_pos(1), cur_pos(2))) %inside the mask
            
            %add point into the Boundary list if it is not already in it
            %prevents multiple storage of the same point at 1 pixel corners
            if ~((Boundary(end,1) == cur_pos(1)) & (Boundary(end,2) == cur_pos(2)))
                Boundary = [Boundary; cur_pos];
            end
            
            delta = [-delta(2), delta(1)]; % turn_left
            cur_pos = cur_pos + delta;
        else %outside the mask
            delta = [delta(2), -delta(1)]; %turn_right
            cur_pos = cur_pos + delta;
        end
    end %while
else
    error('The length of the delta-vector used to step around the boundary is not 1.');
end


% end SA_traceBoundary
