% This function takes two instances of type SA_VectorArray and combines
% them to one instance of SA_VectorArray
%
% parameter: 
% VecArr1, VecArr2: of type SA_VectorArray; 
%
% return parameter:
% VecArr: resulting SA_VectorArray

function VecArr = combine(VecArr1, VecArr2);
if (nargin < 2)
    error('Too less input parameter.');
end

VecArr = SA_VectorArray;

if (VecArr1.size + VecArr2.size ~= 0)
    VecArr.size = VecArr1.size + VecArr2.size;
    
    if (VecArr1.size == 0)
        VecArr.stack = VecArr2.stack;
        VecArr.indexArray = VecArr2.indexArray; 
    elseif (VecArr2.size == 0)
        VecArr.stack = VecArr1.stack;
        VecArr.indexArray = VecArr1.indexArray; 
    else % VecArr1.size > 0 & VecArr2.size > 0
        VecArr.stack = [VecArr1.stack; VecArr2.stack];
        
        s = VecArr1.indexArray(end) - 1;
        v = VecArr2.indexArray;
        v = v + ones(size(v)) .* s;
        
         % the last element of the index array is a number that points to
         % the first index of the stack that is empty (end+1). This  is
         % only once needed for an indexArray and thus it is removed from
         % the first indexArray, but kept on at the end of the second one.
        VecArr.indexArray = [VecArr1.indexArray(1:end-1); v];
        
    end
end