% This function extracts information strings out of a list of training
% images. The first indexed image of the first twenty
% folders of a test class are used as training images. 
% The strings are then aligned against each other and a scoring
% matrix is created.
%
% Training Data Information
% The strings that are extracted from the training data is stored a single
% SA_VectorArray. This array is stored with the name 'TrainingDataStrings'
%
% The Alignment Matrix
% The matrix is computed by aligning all strings in the training data
% VectorArray with themselves. The matrix is returned by the function.

function Matrix = D_processTrainingData;

% Create a list of the training data categories
Category = SA_VectorArray;
%Category = insert(Category, ('anchor')');
Category = insert(Category, ('crab')');
Category = insert(Category, ('stopsign')');
Category = insert(Category, ('windsor_chair')');



% create polar scale
fprintf('creating polar scale....\n');
polarScale = SA_getPolarScale(40, 4, 6);



NumImages = 10; % the number of images per training data categorie

RootFolder = 'trainingset'; % root folder of the training data

StringList = SA_VectorArray;
IndexList = []; % matrix of integers that is used to later reconstruct 
                % which strings belong to which image and how long they are
               
StringList2 = SA_VectorArray;
IndexList2 = [];

for (set = 1:size(Category))
    for (image=1:NumImages)
        
        % create DataFolder -> the folder where the images are
        if (image < 10)
            DataFolder = [RootFolder,'/',get(Category,set)','/image_000', num2str(image), '-RESULTS/'];
            ColorImage = SA_Image(imread([RootFolder,'/',get(Category,set)','/image_000', num2str(image), '.ppm']));    
        else
            DataFolder = [RootFolder,'/',get(Category,set)','/image_00', num2str(image), '-RESULTS/'];
            ColorImage = SA_Image(imread([RootFolder,'/',get(Category,set)','/image_00', num2str(image), '.ppm']));      
        end
        
        % parse file list
        FileList = D_parseNameFile(DataFolder);
        
        
        %load segmented image
        I = SA_Image(imread([DataFolder, (get(FileList,1))']));
        
        %load edge sum image
        I_e = SA_Image(imread([DataFolder, 'edgeImage_sum2.ppm']));
        
        %load grey value image
        I_g = greyval(ColorImage);
        I_g = equalize(I_g);
        
        show(ColorImage);
        
        %extract boundaries and string information
        fprintf(['processing ', DataFolder, (get(FileList,1))' '\n']);
        [B,S,S2] = SA_extract(I,I_e,I_g, polarScale);
        
        
        % add the strings to a global stringlist    
        StringList = combine(StringList, S);
      
        for (t = 1:size(S)); %for each extracted string
            % this list is used to be able to reconstruct the alignment
            % matrix (which entry belongs to which image)
            % set/image/1 = first image of the image'st folder of set'st
            % set (category)
            % the last number is the size of the string
            IndexList = [IndexList; [set, image, 1, size(S,t)]];
        end
        
        % add the strings to a global stringlist    
        StringList2 = combine(StringList2, S2);
      
        for (t = 1:size(S2)); %for each extracted string
            % this list is used to be able to reconstruct the alignment
            % matrix (which entry belongs to which image)
            % set/image/1 = first image of the image'st folder of set'st
            % set (category)
            % the last number is the size of the string
            IndexList2 = [IndexList2; [set, image, 1, size(S2,t)]];
        end
        
    end
end

% save string data 
fprintf('\n');
fprintf('saving StringList\n');
save(StringList,'TrainingDataStrings_EdgeSum');
save(StringList2,'TrainingDataStrings_GreyVal');
dlmwrite('@SA_VectorArray/saves/TrainingData_IndexList.txt', IndexList, '&');
dlmwrite('@SA_VectorArray/saves/TrainingData_IndexList2.txt', IndexList2, '&');



%computing alignment matrix
%fprintf('\n');
%fprintf('computing alignment matrix\n');
%Matrix = SA_alignmentMatrix(StringList, StringList, 2, 0.001, 5);

%saving alignment matrix
%dlmwrite('@SA_VectorArray/saves/TrainingData_EdgeSum_AlignmentMatrix.txt', Matrix, '&');
%fprintf('done.\n');


