% SA_alignmentMatrix computes the score matrix for two lists of strings

function [ScoreMatrix, NormMatrix] = SA_alignmentMatrix(VecArr1, VecArr2, Alignment, GapPenalty, ScoreTreshold);
if (nargin < 4)
    error('Too less input parameter.');
end
if ((Alignment < 1) | (Alignment > 4))
    error('Alignment parameter: 1=globalAlignment, 2=localAlignment, 3=repeatedMatches, 4=overlapMatches.');
end
if ((Alignment > 2) & (nargin < 5)) % 3 and 4 use Treshold parameter, 1 and 2 do not
    error('Treshold parameter missing.');
end
   
ScoreMatrix = zeros(size(VecArr1), size(VecArr2));
for (i=1:size(VecArr1))
    fprintf(['Alignment: ', num2str(i), '/', num2str(size(VecArr1)), '\n']);
    for (j=1:size(VecArr2))
        switch Alignment;
            case 1
                sol = SA_globalAlignment(get(VecArr1,i), get(VecArr2,j), GapPenalty);
            case 2
                sol = SA_localAlignment(get(VecArr1,i), get(VecArr2,j), GapPenalty);
            case 3
                sol = SA_repeatedMatchesAlignment(get(VecArr1,i), get(VecArr2,j), GapPenalty, ScoreTreshold);
            case 4
                sol = SA_overlapMatchesAlignment(get(VecArr1,i), get(VecArr2,j), GapPenalty, ScoreTreshold);
        end
        ScoreMatrix(i,j) = sol(1,1);
        NormMatrix(i,j) = sol(2,1);
    end
end