% the function score is the used similarity function for the alignment process
% here it is the sample correlation of the two vectors x and y.
% x and y are expected to have the same size and to be [k x 1] vectors.
function Value = score(x, y);
if ((size(x,1) ~= size(y,1)) | (size(x,2) ~= size(y,2)))
    error('In function F: the parameter vectors x and y have different size');
end

n = size(x,1);

% compute the mean values of x and y
sum_x = 0;
sum_y = 0;
for (i=1:n) 
    sum_x = sum_x + x(i);
    sum_y = sum_y + y(i);
end
x_mean = sum_x / n;
y_mean = sum_y / n;

% compute sum((x - x_mean)*(y - y_mean))
% and
% compute standard deviation s_x and s_y for the vectors x and y
sum = 0;
s_x = 0;
s_y = 0;
for (i=1:n)
    sum = sum + ((x(i) - x_mean)*(y(i) - y_mean));
    
    s_x = s_x + (x(i) - x_mean)^2;  
    s_y = s_y + (y(i) - y_mean)^2;
end
s_x = sqrt(s_x/n);
s_y = sqrt(s_y/n);

% compute the correlation
Value = sum/((n - 1)*s_x*s_y);
