% this function evaluates the grey values of a grey value image 
% at the boundaries of the patches
%
% GreyImage is the SA_Image with the grey informations
% Boundaries is a SA_VectorArray with the boundaries of interest
% PolarScale is a SA_VectorArray that divides space to evaluate
% distance is the number of pixel between each spot to be tested

function GreyStrings = SA_evaluateGreyValue(GreyImg, Boundaries, PolarScale, Distance);
    
if (nargin < 4) 
    error('Too less input arguments');
end


% for every boundary in Boundaries
GreyStrings = SA_VectorArray; 
for (bounds=1 : size(Boundaries))
    boundary = get(Boundaries,bounds);
    
    % step with steps of distance Distance
    step_pos = 1; 
    GreyString = [[]]; % The string for a boundary
    while (step_pos < size(boundary,1))
        position = boundary(step_pos,:);
        
        % evaluate for each bin of the PolarScale
        info_vector = []; %  = Information vector for a specific position
        for (polar_bin=1 : size(PolarScale))
            bin = get(PolarScale, polar_bin);
            
            % and for each point in the bin sum up the grey value of the
            % picture
            greyvalue = double(0);
            for (bin_pos=1 : size(bin)) 
                eval_pos = position + bin(bin_pos,:);
                
                greyvalue = greyvalue + double(get(GreyImg, eval_pos(1), eval_pos(2)));
            end % for
           
            
        info_vector = [info_vector, greyvalue];
 
        end % for
    GreyString = [GreyString;info_vector];
        
    step_pos = step_pos + Distance;
    end % while 
GreyStrings = insert(GreyStrings, GreyString);
    
end % for boudnaries