% extract information strings from Image using EdgeImg and GreyImg
% EdgeSumStr: the string information along the boundaries using EdgeSum
% image
%
% EdgeSumStr: the string information along the boundaries using EdgeSum img
% GreyValStr: the string information along the boundaries using Grey SegImg


function [Boundaries, EdgeSumStr, GreyValStr] = SA_extract(SegImg, EdgeImg, GreyImg, polarScale);
if (nargin < 2) 
    error('Too less input arguments.');
end

% extract boundaries
fprintf('extracting boundaries....\n');
Boundaries = getBoundaries(SegImg);

% postprocess boundaries
fprintf('postprocessing boundaries....\n');
Boundaries = sort(Boundaries); % sort boundaries from the longest to the smallest
Boundaries = removeSmallerThan(Boundaries, 100); % remove to short boundaries
Boundaries = SA_prepareBoundaries(Boundaries, 5, size(SegImg)); % remove unwanted stuff
Boundaries = keepFirst(Boundaries, 3); % removes all boundaries that are not the 4 largest
Boundaries = SA_extendBoundaries(Boundaries, 0.5); % extend by 10%


% extract edge sum string
fprintf('extracting edge sum information....\n');
EdgeSumStr = SA_evaluateEdgeSum(EdgeImg, Boundaries, polarScale, 30);

% extract edge sum string
fprintf('extracting grey value information....\n');
GreyValStr = SA_evaluateGreyValue(GreyImg, Boundaries, polarScale, 30);

fprintf('done!\n');