% This function takes a SA_VectorArray with [M x 2] elements that represent
% a string of positions on the image.
%
% The position-strings are prepared for further use by removing all
% positions that are closer to the boundary of the image than (Framewidth+1)
%
% Furthermore the string with the most positions to close to the images
% frame will be removed entirely.
%
% And one more step is done: The boundaries are rearranged such that the 
% start position is the position with the smalles y value of all for each 
% boundarie

function PrepVA = SA_prepareBoundaries(VecArr, Framewidth, ImgSize);
if (nargin<3) 
    error('Too less input arguments');
end
if (~nargout)
    error('No output variable.');
end

PrepVA = SA_VectorArray;
if (size(VecArr)<1)
    warning('The passed SA_VectorArray is empty.');
else
% now we can start
worst_frameLen = -1;
worst_element = [[]];
for (j=1:size(VecArr)) % for each boundary:
    % get new boundary from VecArr
    b = get(VecArr,j);
    
    % delete and count frame positions
    count = 0;
    new_b = [[]];
    for (i=1:size(b))
        if ((b(i,1) <= (Framewidth+1)) | (b(i,2) <= (Framewidth+1)) | (b(i,1) >= (ImgSize(1) - (Framewidth))) | (b(i,2) >= (ImgSize(2) - (Framewidth))))
            % if the position is part of the images frame
            count = count + 1;
        else
            % the position is not part of the images frame
            new_b = [new_b;b(i,:)];
        end
    end
    
    % now see if the current element has the longest frame part
    if (count > worst_frameLen) %current element has longer frame part
        worst_frameLen = count;
        if (size(worst_element,1) > 0 )
            PrepVA = insert(PrepVA, rearrange(worst_element));
        end
        worst_element = new_b;
    else % current element has shorter frame part than the best until now
        PrepVA = insert(PrepVA, rearrange(new_b));
    end
end
end


% rearrange rotates the content in Vector such, that the first [1 x 2]
% vector (= position) is the one with the largest y value
function RotVec = rearrange(Vector);
if (size(Vector,1) > 1)
    % find index of first max(y) in Vector
    [value,index] = max(Vector(:,2));

    % index is the first row
    if (index == 1)
        RotVec = Vector;
    
    % index is at the end
    elseif (index == size(Vector,1))
        RotVec = [Vector(end,:);Vector(1:end-1,:)];
    
    % normal case    
    else 
        RotVec = [Vector(index:end,:);Vector(1:index-1,:)];  
    end
else % size(Vector,1) <= 1
    RotVec = Vector;
end
% end rearrange