% This function computes a repeated matches alignment score for two stings
% of vectors
%
% The parameter strings String1 and String2 are expected to have the
% following form:
% [N x k] Matrix with N the size of the string and k the lenght of the
% vector. Bothe String1 and String2 are expected to have the same k. N may
% be different.
%
% The return parameter Score is a [(k+1) x 1] Matrix. The first element is
% the score of the alignment process itself. The k remaining elements
% represent the optimal alignment. 1 = match, 2 = gap in String1, 3 = gap
% in String2, -1 = ignore element in String1, -2 = ignore element in
% String2, -3 = restart String1, -4 = restart String1


function Score = SA_repeatedMatchesAlignment(String1, String2, GapPenalty, ScoreTreshold);
if (nargin < 4)
    error('Too less input parameter.');
end
if (size(String1,2) ~= size(String2,2)) 
    error('The vectors of the string (row size of String1 and String2) dont have the same size.');
end
k = size(String1,2); % size of the vectors to be compared
M = size(String1,1); % size of the first string (height of sa-matrix)
N = size(String2,1); % size of the second string (width of sa_matrix)

sa_matrix = zeros(M+1,N+1); % +1 because first row and column are placeholder 
                            % with zeros, +2 because we need that to compute 
                            % the total score in an extra column
                            
sa_align = zeros(M+1,N+1);  % track back matrix
                            
%%%%%%%%%%%
%PARAMETER%
%%%%%%%%%%%

% gap penalty parameter:
d = GapPenalty;

% threshold for scores:
T = ScoreTreshold;



% record max score:
max_score = 0;

% here we go:
for (j=2:N+1) % for each column
    
        
       % i ==1
       
            % 1) Fill in first row with F(i,0)=max[F(1,j-1); F(i,j-1)-T] for i=2...M+1
            F_max = 0; % F_max will be the max F(i,j-1)-T for i=2..M+1
            i_max = -1;
            for (t=2:M+1)
                if (sa_matrix(t,j-1)-T) > F_max
                    F_max = sa_matrix(t,j-1) - T;
                    i_max = t;
                end
            end
            [sa_matrix(1,j), I] = max([sa_matrix(1,j-1); F_max]);
            if (I==1) %gap in String2
                sa_align(1,j) = 3;
            else %go down to i_max
                sa_align(1,j) = -i_max; % minus because the + values are already used
            end
            
    for (i=2:M+1) % each row element
            % 2) here the rest as usual
            
            % vectors to compare:
            v1 = String1(i-1,:)';
            v2 = String2(j-1,:)';
        
            % options for the path:
            F1 = sa_matrix(i-1,j-1) + score(v1,v2); % match = arrow diagonal up-left
            F2 = sa_matrix(i-1,j) - d; % gap in String2 = arrow up
            F3 = sa_matrix(i,j-1) - d; % gap in String1 = arrow left
            F4 = sa_matrix(1,j); % go back up
        
            [F,I] = max([F1,F2,F3,F4]);
        
            % update matrix
            sa_matrix(i,j) = F;
            sa_align(i,j) = I;
        end
    end

% compute total score in an extra row (j = N+2)
j = N+2;

% find max score trough last column
F_max = 0; 
for (t=2:M+1)
    if (sa_matrix(t,j-1)-T) > F_max
        F_max = sa_matrix(t,j-1) - T;
    end
end   

% scire = max of max value in last column - T or top right value in matrix
[Score,I] = max([sa_matrix(1,N+1); F_max]);

%sa_matrix

% compute alignment backtracking (does not really work yet)
%m = I; n = N+1;
alignment = [];
%while (sa_align(m,n)~=0)
%    alignment = [sa_align(m, n); alignment];
%    if (sa_align(m,n) == 1) % diagonal
%        m = m-1; n  = n-1;
%    elseif (sa_align(m,n) == 2) % up
%        m = m-1;
%    elseif (sa_align(m,n) == 3) % left
%        n = n-1;
%    elseif (sa_align(m,n) < 0) % jump down
%        m = - sa_align(m,n);
%        n = n-1;
%        % >>>>>> Insert Token to align <<<<<<<<<<<
%        alignment(1) = (m+10); % m+10 because the numbers 1-10 are reserved
%    end
%end


%m = I; n = N+1;
%alignlen = 0;
%while (sa_align(m,n)~=0)
%    alignlen = alignlen + 1;
%    if (sa_align(m,n) == 1) % diagonal
%        m = m-1; n  = n-1;
%    elseif (sa_align(m,n) == 2) % up
%        m = m-1;
%    elseif (sa_align(m,n) == 3) % left
%        n = n-1;
%    elseif (sa_align(m,n) < 0) % jump down
%        m = - sa_align(m,n);
%        n = n-1;
%    end
%end

Score = [Score; 1];




% the function score is the used similarity function for the alignment process
% here it is the sample correlation of the two vectors x and y.
% x and y are expected to have the same size and to be [k x 1] vectors.
function Value = score(x, y);
if ((size(x,1) ~= size(y,1)) | (size(x,2) ~= size(y,2)))
    error('In function F: the parameter vectors x and y have different size');
end

n = size(x,1);

% compute the mean values of x and y
sum_x = 0;
sum_y = 0;
for (i=1:n) 
    sum_x = sum_x + x(i);
    sum_y = sum_y + y(i);
end
x_mean = sum_x / n;
y_mean = sum_y / n;

% compute sum((x - x_mean)*(y - y_mean))
% and
% compute standard deviation s_x and s_y for the vectors x and y
sum = 0;
s_x = 0;
s_y = 0;
for (i=1:n)
    sum = sum + ((x(i) - x_mean)*(y(i) - y_mean));
    
    s_x = s_x + (x(i) - x_mean)^2;  
    s_y = s_y + (y(i) - y_mean)^2;
end
s_x = sqrt(s_x/n) + 0.000001;
s_y = sqrt(s_y/n) + 0.000001;

% compute the correlation
Value = sum/((n - 1)*s_x*s_y);

