% This function visualizes the alignment of two boundaries by 
% decoding the alignment string and connecting the aligned parts 
% with a line.
%
% Parameter:
% Boundary1: [Mx2] Matrix that represent the boundary positions
% Boundary2: [Nx2] Matrix that represent the other boundary positions
% Distance: uint; the dist between wich the sting informations were taken
% Alignment: [1xS] Matrix; The result of the alignment (without the score)
%
% Return Parameter:
% Image: SA_Image with the boundaries drawn.

function Image = SA_visualizeAlignment(Boundary1, Boundary2, Distance, Alignment);
b = SA_VectorArray;
b = insert(b, Boundary1);
b = insert(b, Boundary2);

fprintf('Creating empty image....\n');
Image = SA_Image(zeros(350,350,3)); % new image

% draw Boundaries
fprintf('Drawing boundaries....\n');
Image = drawBoundaries(Image, b, [1,0,0;0,0,1]); % Boundary1=red, Boundary2=blue
show(Image);

% draw positions to align (Dots where information was taken)
% Boundary1
step_pos = 1;
fprintf('Drawing dots....\n');
while (step_pos <= size(Boundary1,1))
    Image = drawDot(Image, Boundary1(step_pos,:), 4, [1,0,0]);
    step_pos = step_pos + Distance;
end
% Boundary2
step_pos = 1;
while (step_pos <= size(Boundary2,1))
    Image = drawDot(Image, Boundary2(step_pos,:), 4, [0,0,1]);
    step_pos = step_pos + Distance;
end
Show(Image);

%decode alignment
step_pos1 = 1;
step_pos2 = 1;
fprintf('Visualizing alignment....\n');
for(k=1:size(Alignment,1)) 
    if (Alignment(k,1) == -2) % ignore element in String2
        step_pos2 = step_pos2 + Distance;
    elseif (Alignment(k,1) == -1) % ignore element in String1 
        step_pos1 = step_pos1 + Distance;
    elseif (Alignment(k,1) == 1) % match
        Image = drawLine(Image, Boundary1(step_pos1,:), Boundary2(step_pos2,:), [0.2,1,0.2]);
        step_pos1 = step_pos1 + Distance;
        step_pos2 = step_pos2 + Distance;
    elseif (Alignment(k,1) == 2) % gap in string1
        step_pos1 = step_pos1 + Distance;
    elseif (Alignment(k,1) == 3) % gap in string2
        step_pos2 = step_pos2 + Distance;
    elseif (Alignment(k,1) > 10)
        step_pos1 = 1 + (Alignment(k,1)-10)*Distance;
    end
    show(Image);
end

